@@ -22,14 +22,18 @@
 
 #include "bookmarks-site-tb-widget.h"
 #include "galeon-marshal.h"
-#include "gul-gobject-misc.h"
 #include "bookmarks-widgets-private.h"
+#include "bookmarks-dnd.h"
 
 #include <gtk/gtkbutton.h>
 
 /**
  * Private data
  */
+#define GB_SITE_TB_WIDGET_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), \
+				       GB_TYPE_SITE_TB_WIDGET, GbSiteTbWidgetPrivate))
+
+
 struct _GbSiteTbWidgetPrivate 
 {
 	GtkWidget *mainwid;
@@ -38,45 +42,37 @@ struct _GbSiteTbWidgetPrivate
 /**
  * Private functions, only availble from this file
  */
-static void		gb_site_tb_widget_class_init	(GbSiteTbWidgetClass *klass);
-static void		gb_site_tb_widget_init		(GbSiteTbWidget *w);
 static void		gb_site_tb_widget_finalize_impl	(GObject *o);
 static void		gb_site_tb_widget_rebuild_impl	(GbTbWidget *w);
 static void		gb_site_tb_widget_clicked_cb	(GtkButton *button, GbSiteTbWidget *w);
 
-static gpointer gb_tb_widget_class;
 
 /**
  * GbSiteTbWidget object
  */
 
-MAKE_GET_TYPE (gb_site_tb_widget, "GbSiteTbWidget", GbSiteTbWidget, gb_site_tb_widget_class_init, 
-	       gb_site_tb_widget_init, GB_TYPE_TB_WIDGET);
+G_DEFINE_TYPE (GbSiteTbWidget, gb_site_tb_widget, GB_TYPE_TB_WIDGET);
 
 static void
 gb_site_tb_widget_class_init (GbSiteTbWidgetClass *klass)
 {
 	G_OBJECT_CLASS (klass)->finalize = gb_site_tb_widget_finalize_impl;
 	GB_TB_WIDGET_CLASS (klass)->rebuild = gb_site_tb_widget_rebuild_impl;
-	gb_tb_widget_class = g_type_class_peek_parent (klass);
+
+	g_type_class_add_private (klass, sizeof (GbSiteTbWidgetPrivate));
 }
 
 static void 
 gb_site_tb_widget_init (GbSiteTbWidget *w)
 {
-	GbSiteTbWidgetPrivate *p = g_new0 (GbSiteTbWidgetPrivate, 1);
+	GbSiteTbWidgetPrivate *p = GB_SITE_TB_WIDGET_GET_PRIVATE (w);
 	w->priv = p;
 }
 
 static void
 gb_site_tb_widget_finalize_impl (GObject *o)
 {
-	GbSiteTbWidget *w = GB_SITE_TB_WIDGET (o);
-	GbSiteTbWidgetPrivate *p = w->priv;
-	
-	g_free (p);
-	
-	G_OBJECT_CLASS (gb_tb_widget_class)->finalize (o);
+	G_OBJECT_CLASS (gb_site_tb_widget_parent_class)->finalize (o);
 }
 
 GbSiteTbWidget *
@@ -114,6 +110,7 @@ gb_site_tb_widget_rebuild_impl (GbTbWidget *gtw)
 	GTK_WIDGET_SET_FLAGS (GTK_BUTTON (p->mainwid), GTK_CAN_FOCUS);
 
 	gb_tb_widget_setup_context_menu (gtw, p->mainwid);
+	gb_bookmark_dnd_drag_source_set (p->mainwid, GB_BOOKMARK (site));
 }
 
 static void
