@@ -1,3 +1,4 @@
+/* -*- mode: c; c-style: k&r; c-basic-offset: 8 -*- */
 /*
  *  Copyright (C) 2002  Ricardo Fernndez Pascual
  *
@@ -26,10 +27,11 @@
 #include "bookmarks-context-menu-several.h"
 #include "bookmarks-single-editor.h"
 #include "bookmarks-util.h"
-#include "gul-gobject-misc.h"
 #include "galeon-marshal.h"
 #include "gul-string.h"
+#include "pixbuf-cache.h"
 #include "galeon-debug.h"
+#include "galeon-dnd.h"
 
 #include <gtk/gtkcellrenderertext.h>
 #include <gtk/gtkcellrenderertoggle.h>
@@ -40,6 +42,10 @@
 /**
  * Private data
  */
+#define GB_TREE_VIEW_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object), \
+				       GB_TYPE_TREE_VIEW, GbTreeViewPrivate))
+
+
 struct _GbTreeViewPrivate 
 {
 	GSList *selected;
@@ -50,13 +56,14 @@ struct _GbTreeViewPrivate
 	gboolean location_visible;
 	gboolean check_visible;
 	gboolean autoexpand_roots;
+	gboolean editable;
+	GtkCellRendererText *renderer_name;
+	GtkCellRendererText *renderer_url;
 };
 
 /**
  * Private functions, only availble from this file
  */
-static void		gb_tree_view_class_init			(GbTreeViewClass *klass);
-static void		gb_tree_view_init			(GbTreeView *e);
 static void		gb_tree_view_finalize_impl		(GObject *o);
 static void		gb_tree_view_selection_changed_cb	(GtkTreeSelection *treeselection, GbTreeView *e);
 static void		gb_tree_view_selection_add_selected	(GtkTreeModel *model, GtkTreePath *path, 
@@ -67,17 +74,37 @@ static gboolean 	gb_tree_view_treeview_button_press_event_cb (GtkWidget *widget,
 								     GbTreeView *e);
 static void 		gb_tree_view_ensure_selected_path	(GtkTreeSelection *sel, 
 								 GtkTreePath *path);
+static void 		gb_tree_view_drag_begin_cb		(GtkWidget *widget,
+								 GdkDragContext *drag_context,
+								 GbTreeView *tv);
+static void		gb_tree_view_name_edited_cb		(GtkCellRendererText *cell_renderer_text,
+								 const gchar *path,
+								 const gchar *new_text,
+								 GbTreeView *tv);
+static void		gb_tree_view_url_edited_cb		(GtkCellRendererText *cell_renderer_text,
+								 const gchar *path,
+								 const gchar *new_text,
+								 GbTreeView *tv);
+static void		gb_tree_view_cursor_changed_cb		(GtkTreeView*gtv,
+								 GbTreeView *tv);
 
 
+G_DEFINE_TYPE (GbTreeView, gb_tree_view, GTK_TYPE_TREE_VIEW);
+
 enum
 {
-	TARGET_GTK_TREE_MODEL_ROW
+	TARGET_GTK_TREE_MODEL_ROW = 10
 };
 static GtkTargetEntry tree_view_row_targets[] = {
 	{ "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_APP, TARGET_GTK_TREE_MODEL_ROW }
 };
 
-static gpointer gtk_tree_view_class;
+static GtkTargetEntry tree_view_row_dest_targets[] = {
+	{ "GTK_TREE_MODEL_ROW", GTK_TARGET_SAME_APP, TARGET_GTK_TREE_MODEL_ROW },
+        { GALEON_DND_URL_TYPE,        0, GALEON_DND_URL },
+        { GALEON_DND_URI_LIST_TYPE,   0, GALEON_DND_URI_LIST }
+};
+
 
 /* signals enums and ids */
 enum GbTreeviewSignalsEnum {
@@ -92,9 +119,6 @@ static gint GbTreeViewSignals[GB_TREE_VIEW_LAST_SIGNAL];
  * TreeView object
  */
 
-MAKE_GET_TYPE (gb_tree_view, "GbTreeView", GbTreeView, gb_tree_view_class_init, 
-	       gb_tree_view_init, GTK_TYPE_TREE_VIEW);
-
 static void
 gb_tree_view_class_init (GbTreeViewClass *klass)
 {
@@ -111,7 +135,7 @@ gb_tree_view_class_init (GbTreeViewClass *klass)
 		"bookmark-double-clicked", G_OBJECT_CLASS_TYPE (klass),  
 		G_SIGNAL_RUN_LAST,
                 G_STRUCT_OFFSET (GbTreeViewClass, bookmark_double_clicked), 
-		gul_boolean_handled_accumulator, NULL, 
+		g_signal_accumulator_true_handled, NULL, 
 		galeon_marshal_BOOLEAN__OBJECT,
 		G_TYPE_BOOLEAN, 1, GB_TYPE_BOOKMARK);
 	GbTreeViewSignals[GB_TREE_VIEW_BOOKMARK_CHECK_TOGGLED] = g_signal_new (
@@ -122,7 +146,8 @@ gb_tree_view_class_init (GbTreeViewClass *klass)
 		galeon_marshal_VOID__OBJECT,
 		G_TYPE_NONE, 1, GB_TYPE_BOOKMARK);
 
-	gtk_tree_view_class = g_type_class_peek_parent (klass);
+
+	g_type_class_add_private (klass, sizeof (GbTreeViewPrivate));
 }
 
 static void
@@ -201,7 +226,7 @@ gb_tree_view_treeview_row_activated_cb (GtkTreeView *tree_view,
 static void 
 gb_tree_view_init (GbTreeView *tv)
 {
-	GbTreeViewPrivate *p = g_new0 (GbTreeViewPrivate, 1);
+	GbTreeViewPrivate *p = GB_TREE_VIEW_GET_PRIVATE (tv);
 	GtkTreeSelection *s;
 	GtkCellRenderer *renderer;
 	GtkTreeViewColumn *column;
@@ -211,7 +236,8 @@ gb_tree_view_init (GbTreeView *tv)
 	p->location_visible = TRUE;
 	p->check_visible = FALSE;
 	p->autoexpand_roots = TRUE;
-	
+	p->editable = TRUE;
+
 	s = gtk_tree_view_get_selection (GTK_TREE_VIEW (tv));
 	gtk_tree_selection_set_mode (s, GTK_SELECTION_MULTIPLE);
 	g_signal_connect (s, "changed", G_CALLBACK (gb_tree_view_selection_changed_cb), tv);
@@ -242,6 +268,9 @@ gb_tree_view_init (GbTreeView *tv)
 					     NULL);
 	
 	renderer = gtk_cell_renderer_text_new ();
+	p->renderer_name = GTK_CELL_RENDERER_TEXT (renderer);
+	g_object_set (G_OBJECT (renderer), "editable", p->editable, NULL);
+	g_signal_connect (renderer, "edited", G_CALLBACK (gb_tree_view_name_edited_cb), tv);
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_set_attributes (column, renderer,
                                              "text", GB_TREE_MODEL_COL_TITLE, 
@@ -250,9 +279,12 @@ gb_tree_view_init (GbTreeView *tv)
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (tv), column);
 	gtk_tree_view_set_expander_column (GTK_TREE_VIEW (tv), column);
-	
+
 	column = gtk_tree_view_column_new ();
 	renderer = gtk_cell_renderer_text_new ();
+	p->renderer_url = GTK_CELL_RENDERER_TEXT (renderer);
+	g_object_set (G_OBJECT (renderer), "editable", p->editable, NULL);
+	g_signal_connect (renderer, "edited", G_CALLBACK (gb_tree_view_url_edited_cb), tv);
 	gtk_tree_view_column_pack_start (column, renderer, TRUE);
 	gtk_tree_view_column_set_attributes (column, renderer,
                                              "text", GB_TREE_MODEL_COL_URL, 
@@ -273,12 +305,16 @@ gb_tree_view_init (GbTreeView *tv)
 						GDK_ACTION_MOVE | GDK_ACTION_COPY);
 	
 	gtk_tree_view_enable_model_drag_dest (GTK_TREE_VIEW (tv),
-					      tree_view_row_targets,
-					      G_N_ELEMENTS (tree_view_row_targets),
+					      tree_view_row_dest_targets,
+					      G_N_ELEMENTS (tree_view_row_dest_targets),
 					      GDK_ACTION_MOVE | GDK_ACTION_COPY);
 	
+	g_signal_connect_after (tv, "drag-begin", 
+				G_CALLBACK (gb_tree_view_drag_begin_cb), tv);
+
 	p->double_click_action = GB_TV_EDIT;
 
+	g_signal_connect (tv, "cursor-changed", G_CALLBACK (gb_tree_view_cursor_changed_cb), tv);
 }
 
 static void
@@ -292,9 +328,8 @@ gb_tree_view_finalize_impl (GObject *o)
 	g_slist_free (p->selected);
 	if (p->location_column) g_object_unref (p->location_column);
 	if (p->check_column) g_object_unref (p->check_column);
-	g_free (p);
 	
-	G_OBJECT_CLASS (gtk_tree_view_class)->finalize (o);
+	G_OBJECT_CLASS (gb_tree_view_parent_class)->finalize (o);
 }
 
 GbTreeView *
@@ -499,6 +534,14 @@ gb_tree_view_select (GbTreeView *tv, GbBookmark *b)
 	g_slist_free (l);
 }
 
+void
+gb_tree_view_select_add (GbTreeView *tv, GbBookmark *b)
+{
+	GSList *l = g_slist_prepend (NULL, b);
+	gb_tree_view_select_list_add (tv, l);
+	g_slist_free (l);
+}
+
 static void
 gb_tree_view_expand_path (GbTreeView *tv, const GtkTreePath *path)
 {
@@ -519,7 +562,7 @@ gb_tree_view_expand_path (GbTreeView *tv, const GtkTreePath *path)
 }
 
 void
-gb_tree_view_select_list (GbTreeView *tv, const GSList *l)
+gb_tree_view_select_list_add (GbTreeView *tv, const GSList *l)
 {
 	GtkTreeSelection *s = gtk_tree_view_get_selection (GTK_TREE_VIEW (tv));
 	GtkTreeModel *tm = gtk_tree_view_get_model (GTK_TREE_VIEW (tv));
@@ -531,8 +574,6 @@ gb_tree_view_select_list (GbTreeView *tv, const GSList *l)
 		return;
 	}
 
-	gtk_tree_selection_unselect_all (s);
-
 	for (li = l; li; li = li->next)
 	{
 		GbBookmark *b = li->data;
@@ -555,6 +596,22 @@ gb_tree_view_select_list (GbTreeView *tv, const GSList *l)
 	}
 }
 
+void
+gb_tree_view_select_list (GbTreeView *tv, const GSList *l)
+{
+	GtkTreeSelection *s = gtk_tree_view_get_selection (GTK_TREE_VIEW (tv));
+	GtkTreeModel *tm = gtk_tree_view_get_model (GTK_TREE_VIEW (tv));
+	
+	if (!tm)
+	{
+		return;
+	}
+
+	gtk_tree_selection_unselect_all (s);
+	
+	gb_tree_view_select_list_add (tv, l);
+}
+
 void
 gb_tree_view_ensure_selected (GbTreeView *tv, GbBookmark *b)
 {
@@ -565,6 +622,16 @@ gb_tree_view_ensure_selected (GbTreeView *tv, GbBookmark *b)
 	}
 }
 
+void
+gb_tree_view_ensure_selected_add (GbTreeView *tv, GbBookmark *b)
+{
+	GbTreeViewPrivate *p = tv->priv;
+	if (g_slist_find (p->selected, b) == NULL)
+	{
+		gb_tree_view_select_add (tv, b);
+	}
+}
+
 void
 gb_tree_view_ensure_expanded (GbTreeView *tv, GbBookmark *b)
 {
@@ -625,3 +692,85 @@ gb_tree_view_set_autoexpand_roots (GbTreeView *tv, gboolean val)
 	GbTreeViewPrivate *p = tv->priv;
 	p->autoexpand_roots = val;
 }
+
+static void
+gb_tree_view_drag_begin_cb (GtkWidget *widget,
+			    GdkDragContext *drag_context,
+			    GbTreeView *tv)
+{
+	/* This doesn't look very nice :-(
+	   gtk_drag_set_icon_stock (drag_context, GALEON_STOCK_BOOKMARK, 0, 0);
+	*/
+	gtk_drag_set_icon_default (drag_context);
+}
+
+static void
+gb_tree_view_name_edited_cb (GtkCellRendererText *cell_renderer_text,
+			     const gchar *spath,
+			     const gchar *new_text,
+			     GbTreeView *tv)
+{
+	GtkTreePath *path = gtk_tree_path_new_from_string (spath);
+	GbTreeModel *model = (GbTreeModel *) gtk_tree_view_get_model (GTK_TREE_VIEW (tv));
+	GtkTreeIter iter;
+
+	g_return_if_fail (model && GB_IS_TREE_MODEL (model));
+
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path))
+	{
+		GbBookmark *b = gb_tree_model_bookmark_from_iter (model, &iter);
+		if (b)
+		{
+			gb_bookmark_set_name (b, new_text);
+		}
+	}
+	gtk_tree_path_free (path);
+}
+
+static void
+gb_tree_view_url_edited_cb (GtkCellRendererText *cell_renderer_text,
+			    const gchar *spath,
+			    const gchar *new_text,
+			     GbTreeView *tv)
+{
+	GtkTreePath *path = gtk_tree_path_new_from_string (spath);
+	GbTreeModel *model = (GbTreeModel *) gtk_tree_view_get_model (GTK_TREE_VIEW (tv));
+	GtkTreeIter iter;
+
+	g_return_if_fail (model && GB_IS_TREE_MODEL (model));
+
+	if (gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path))
+	{
+		GbBookmark *b = gb_tree_model_bookmark_from_iter (model, &iter);
+		if (b && GB_IS_SITE (b))
+		{
+			gb_site_set_url (GB_SITE (b), new_text);
+		}
+	}
+	gtk_tree_path_free (path);
+}
+
+static void
+gb_tree_view_cursor_changed_cb (GtkTreeView *gtv,
+				GbTreeView *tv)
+{
+	GbTreeViewPrivate *p = tv->priv;
+	GtkTreePath *path;
+	gtk_tree_view_get_cursor (gtv, &path, NULL);
+	if (path)
+	{
+		GbTreeModel *model = (GbTreeModel *) gtk_tree_view_get_model (GTK_TREE_VIEW (tv));
+		GtkTreeIter iter;
+		if (gtk_tree_model_get_iter (GTK_TREE_MODEL (model), &iter, path))
+		{
+			GbBookmark *b = gb_tree_model_bookmark_from_iter (model, &iter);
+			if (b)
+			{
+				g_object_set (G_OBJECT (p->renderer_name), "editable", p->editable && !GB_IS_SEPARATOR (b), NULL);
+				g_object_set (G_OBJECT (p->renderer_url), "editable", p->editable && GB_IS_SITE (b), NULL);
+			}
+		}
+		gtk_tree_path_free (path);
+	}
+}
+
