@@ -17,7 +17,6 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "galeon-embed.h"
 #include "gtkhtml-embed.h"
 
 #include <libgtkhtml/view/htmlview.h>
@@ -138,6 +137,9 @@ impl_shistory_go_nth (GaleonEmbed *embed,
 static gboolean
 impl_shistory_copy (GaleonEmbed *source,
                     GaleonEmbed *dest);
+static gresult
+impl_shistory_clear (GaleonEmbed *source);
+
 static gresult
 impl_scroll (GaleonEmbed *embed, 
              EmbedScrollDirection direction);
@@ -230,44 +232,8 @@ struct GtkhtmlEmbedPrivate
 
 static GtkScrolledWindowClass *parent_class = NULL;
 
-GType 
-gtkhtml_embed_get_type (void)
-{
-        static GType gtkhtml_embed_type = 0;
-
-        if (gtkhtml_embed_type == 0)
-        {
-                static const GTypeInfo our_info =
-                {
-                        sizeof (GtkhtmlEmbedClass),
-                        NULL, /* base_init */
-                        NULL, /* base_finalize */
-                        (GClassInitFunc) gtkhtml_embed_class_init,
-                        NULL,
-                        NULL, /* class_data */
-                        sizeof (GtkhtmlEmbed),
-                        0, /* n_preallocs */
-                        (GInstanceInitFunc) gtkhtml_embed_init
-                };
-
-		static const GInterfaceInfo embed_info =
-		{
-			(GInterfaceInitFunc) galeon_embed_init,	/* interface_init */
-			NULL,					/* interface_finalize */
-			NULL					/* interface_data */
-		};
-
-                gtkhtml_embed_type = g_type_register_static (GTK_TYPE_SCROLLED_WINDOW,
-							     "GtkhtmlEmbed",
-							     &our_info, 
-							     (GTypeFlags)0);
-		g_type_add_interface_static (gtkhtml_embed_type,
-				             GALEON_EMBED_TYPE,
-					     &embed_info);
-        }
-
-        return gtkhtml_embed_type;
-}
+G_DEFINE_TYPE_WITH_CODE (GtkhtmlEmbed, gtkhtml_embed, GTK_TYPE_SCROLLED_WINDOW,
+			 G_IMPLEMENT_INTERFACE (GALEON_TYPE_EMBED, galeon_embed_init));
 
 static void
 galeon_embed_init (GaleonEmbedClass *embed_class)
@@ -306,6 +272,7 @@ galeon_embed_init (GaleonEmbedClass *embed_class)
 	embed_class->shistory_get_pos = impl_shistory_get_pos;
 	embed_class->shistory_go_nth = impl_shistory_go_nth;
 	embed_class->shistory_copy = impl_shistory_copy;
+	embed_class->shistory_clear = impl_shistory_clear;
 	embed_class->scroll = impl_scroll;
 	embed_class->get_security_level = impl_get_security_level;
 	embed_class->find = impl_find;
@@ -363,7 +330,7 @@ gtkhtml_embed_finalize (GObject *object)
         GtkhtmlEmbed *embed;
 
         g_return_if_fail (object != NULL);
-        g_return_if_fail (IS_GTKHTML_EMBED (object));
+        g_return_if_fail (GTKHTML_IS_EMBED (object));
 
 	embed = GTKHTML_EMBED (object);
 
@@ -633,6 +600,12 @@ impl_shistory_copy (GaleonEmbed *source,
 	return G_NOT_IMPLEMENTED;
 }
 
+static gresult
+impl_shistory_clear (GaleonEmbed *embed)
+{
+	return G_NOT_IMPLEMENTED;
+}
+
 static gresult
 impl_scroll (GaleonEmbed *embed, 
              EmbedScrollDirection direction)
