@@ -20,8 +20,8 @@
 #include "config.h"
 #endif
 
-#define MOZILLA_INTERNAL_API
 #include <nscore.h>
+#define MOZILLA_INTERNAL_API
 #include <nsIServiceManager.h>
 #undef MOZILLA_INTERNAL_API
 
@@ -34,6 +34,7 @@
 #include "EventContext.h"
 #include "eel-gconf-extensions.h"
 #include "galeon-embed-prefs.h"
+#include "GaleonJS.h"
 #include "GaleonUtils.h"
 #include "MozillaPrivate.h"
 #include "GulString.h"
@@ -1667,9 +1668,12 @@ nsresult GaleonWrapper::EvaluateJS (const char *script)
 	NS_ENSURE_TRUE (DOMWindow, NS_ERROR_FAILURE);
 
 	PRBool isUndefined = PR_TRUE;
-	GulString ret;
-	rv = MozillaPrivate::EvaluateJS (DOMWindow, GulString(script),
-					 ret, &isUndefined);
+	PRUnichar *rawRet = NULL;
+	rv = GaleonJS::EvaluateJS (DOMWindow, GulString(script).get(),
+				   &rawRet, &isUndefined);
+
+	GulString ret(rawRet);
+	nsMemory::Free(rawRet);
 	NS_ENSURE_SUCCESS (rv, rv);
 
 	if (ret.Length() && ! isUndefined)
