@@ -55,6 +55,9 @@
 #include "prefs-strings.h"
 #include "hig-alert.h"
 
+#define MOZILLA_INTERNAL_API
+#include <nsIServiceManager.h>
+#undef MOZILLA_INTERNAL_API
 #include <nsIChannel.h>
 #include <nsIHttpChannel.h>
 #include <nsIEncodedChannel.h>
