@@ -43,6 +43,9 @@
 #include "GaleonAboutModule.h"
 #include "nsMailtoUrl.h"
 
+#ifdef HAVE_NSICLASSINFOIMPL_H
+#include <nsIClassInfoImpl.h>
+#endif
 #include <nsIGenericFactory.h>
 #include <nsIComponentRegistrar.h>
 #include <nsICategoryManager.h>
