@@ -55,10 +55,11 @@ static const PRInt64 kUnknownSizeInterval = 150000;     /* in microsecs == 150ms
 #ifdef HAVE_NSITRANSFER_H
 #ifdef HAVE_NSIWEBPROGRESSLISTENER2_H
 NS_IMPL_ISUPPORTS4(GProgressListener, nsIWebProgressListener, nsIWebProgressListener2,
+		   nsITransfer, nsISupportsWeakReference)
 #else
 NS_IMPL_ISUPPORTS3(GProgressListener, nsIWebProgressListener,
-#endif
 		   nsITransfer, nsISupportsWeakReference)
+#endif
 #else
 NS_IMPL_ISUPPORTS4(GProgressListener, nsIWebProgressListener, 
 		   nsIDownload, nsITransfer, nsISupportsWeakReference)
@@ -200,6 +201,9 @@ NS_IMETHODIMP GProgressListener::Init(nsIURI *aSource,
 #endif
 				      nsIMIMEInfo *aMIMEInfo,
                                       PRInt64 aStartTime,
+#if HAVE_NSITRANSFER_TEMPFILE
+				      nsILocalFile *aTempFile,
+#endif
 #ifdef HAVE_NSITRANSFER_NSICANCELABLE
 				      nsICancelable *aCancelable)
 #else
@@ -623,15 +627,12 @@ NS_METHOD GProgressListener::
 		remaining = (aMaxTotalProgress - aCurTotalProgress) / speed;
 	}
 
-	if (aMaxTotalProgress < 0)
-		aMaxTotalProgress = G_MAXINT64;
-
 	download_set_progress (mDownload,
 			       elapsed,
 			       remaining,
 			       speed,
 			       aCurTotalProgress,
-			       aMaxTotalProgress);
+			       aMaxTotalProgress < 0 ? G_MAXUINT64 : aMaxTotalProgress);
 
 	/* done */
 	return NS_OK;
