@@ -16,23 +16,21 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include "galeon-config.h"
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "galeon-embed-shell.h"
 #include "mozilla-notifiers.h"
 #include "eel-gconf-extensions.h"
 #include "mozilla-prefs.h"
-#include "MozRegisterComponents.h"
 #include "prefs-strings.h"
 #include "galeon-embed-prefs.h"
 #include "mozilla-i18n.h"
 
+#include <glib/gi18n.h>
 #include <stdio.h>
 #include <string.h>
-#include <locale.h>
-#include <libgnome/gnome-i18n.h>
-#include <stdlib.h>
-#include <sys/utsname.h>
-#include "nsBuildID.h"
 
 static void
 mozilla_own_colors_notifier(GConfClient *client,
@@ -107,12 +105,6 @@ mozilla_proxy_ignore_notifier (GConfClient *client,
 			     GConfEntry *entry,
 			     char *pref);
 
-static void
-mozilla_proxy_autoconfig_notifier (GConfClient *client,
-			           guint cnxn_id,
-			           GConfEntry *entry,
-			           char *pref);
-
 static void
 mozilla_user_agent_notifier(GConfClient *client,
 			    guint cnxn_id,
@@ -164,16 +156,14 @@ conversion_table [] =
 	{ CONF_NETWORK_SSL_PROXY_PORT, INT_PREF, "network.proxy.ssl_port"},
 	{ CONF_NETWORK_SOCKS_PROXY_PORT, INT_PREF, "network.proxy.socks_port"},
 	{ CONF_NETWORK_PROXY_KA, BOOL_PREF, "network.http.proxy.keep-alive"},
-	{ CONF_NETWORK_MEMORY_CACHE, INT_PREF, "browser.cache.memory.capacity"},
 	{ CONF_NETWORK_DISK_CACHE, INT_PREF, "browser.cache.disk.capacity"},
 	{ CONF_NETWORK_CACHE_COMPARE, INT_PREF, "browser.cache.check_doc_frequency"},
 	{ CONF_MOUSE_WHEEL_NOKEY_ACTION, INT_PREF, "mousewheel.withnokey.action"},
 	{ CONF_MOUSE_WHEEL_NOKEY_DEF_STEP, BOOL_PREF, "mousewheel.withnokey.sysnumlines"},
 	{ CONF_MOUSE_WHEEL_NOKEY_STEP, INT_PREF, "mousewheel.withnokey.numlines"},
-	{ CONF_MOUSE_WHEEL_STEP_SIZE, INT_PREF, "mousewheel.withnokey.numlines"},
-	{ CONF_PERSISTENT_COOKIE_WARN, BOOL_PREF, "network.cookie.warnAboutCookies"},
 	{ CONF_PERSISTENT_COOKIES_BEHAVIOR, INT_PREF, "network.cookie.cookieBehavior"},
-	{ CONF_PERSISTENT_COOKIE_LIFETIME, BOOL_PREF, "network.cookie.lifetime.enabled"},
+	{ CONF_PERSISTENT_COOKIES_LIFETIME, INT_PREF, "network.cookie.lifetimePolicy"},
+	{ CONF_PERSISTENT_COOKIE_ACCEPT_SESSION, BOOL_PREF, "network.cookie.alwaysAcceptSessionCookies"},
 	{ CONF_PERSISTENT_PASSWORDS_SAVE, BOOL_PREF, "signon.rememberSignons"},
 	{ CONF_RENDERING_USE_SYSTEM_COLORS, BOOL_PREF, "browser.display.use_system_colors"},
 	{ CONF_DOWNLOADING_DIR, STRING_PREF, "browser.download.dir"},
@@ -209,28 +199,11 @@ custom_notifiers [] =
 	  (GConfClientNotifyFunc) mozilla_socks_version_notifier },
 	{ CONF_NETWORK_PROXY_MODE,
 	  (GConfClientNotifyFunc) mozilla_proxy_mode_notifier },
-	{ CONF_NETWORK_PROXY_AUTO_URL,
-	  (GConfClientNotifyFunc) mozilla_proxy_autoconfig_notifier },
 	{ CONF_NETWORK_PROXY_IGNORE_HOSTS,
 	  (GConfClientNotifyFunc) mozilla_proxy_ignore_notifier },
 	{NULL, NULL}
 };
 
-static void
-mozilla_font_size_notifier (GConfClient *client,
-		            guint cnxn_id,
-		            GConfEntry *entry,
-		            char *pref)
-{
-	char key[255];
-	
-	if (entry->value == NULL) return;
-
-	sprintf (key, "font.%s", pref);
-
-	mozilla_prefs_set_int (key, eel_gconf_get_integer (entry->key));
-}
-
 static void
 mozilla_proxy_mode_notifier (GConfClient *client,
 		             guint cnxn_id,
@@ -313,23 +286,6 @@ mozilla_font_notifier (GConfClient *client,
 	}
 }
 
-static void
-mozilla_proxy_autoconfig_notifier (GConfClient *client,
-		       	           guint cnxn_id,
-		       		   GConfEntry *entry,
-		       		   char *pref)
-{
-	char *url;
-
-	url = eel_gconf_get_string (entry->key);
-
-	if (url)
-	{
-		galeon_embed_shell_load_proxy_autoconf (embed_shell, url);
-		g_free (url);
-	}
-}
-
 static void
 add_notification_and_notify (GConfClient		*client,
 			     const char 		*key,
@@ -364,7 +320,7 @@ add_notification_and_notify (GConfClient		*client,
 	{
 		func (client, cnxn_id, entry, user_data);
 	}
-	gconf_entry_free (entry);
+	gconf_entry_unref (entry);
 }
 
 void 
@@ -410,49 +366,49 @@ mozilla_notifiers_init(MozillaEmbedShell *shell)
 	}
 
 	/* fonts notifiers */
-	for (i = 0; i < LANG_ENC_NUM; i++)
+	for (i = 0; i < num_font_languages; i++)
 	{
 		int k;
 		char *types [] = { "serif", "sans-serif", "cursive", "fantasy", "monospace" };
 		char key[255];
 		char *info;
-		
+		const char* language = font_languages[i].key;
+
 		for (k = 0; k < 5; k++)
 		{
-			info = g_strconcat (types[k], ".", lang_encode_item[i], NULL);
+			info = g_strconcat (types[k], ".", language, NULL);
 			
 			sprintf (key, "%s_%s_%s", CONF_RENDERING_FONT, 
-			 	 types[k], 
-                 	 	 lang_encode_item[i]);
-			galeon_notification_add (key,
-						 (GConfClientNotifyFunc)mozilla_font_notifier,
-						  info,
-						  &mozilla_notifiers);
+			 	 types[k], language);
+			add_notification_and_notify (client,
+						     key,
+						     (GConfClientNotifyFunc)mozilla_font_notifier,
+						     info);
 			font_infos = g_list_append (font_infos, info);
 		}
 
-		sprintf (key, "%s_%s", CONF_RENDERING_FONT_MIN_SIZE, lang_encode_item[i]);
-		info = g_strconcat ("minimum-size", ".", lang_encode_item[i], NULL);
-		galeon_notification_add (key,
-					 (GConfClientNotifyFunc)mozilla_font_size_notifier,
-					 info,
-				         &mozilla_notifiers);
+		sprintf (key, "%s_%s", CONF_RENDERING_FONT_MIN_SIZE, language);
+		info = g_strconcat ("font.minimum-size", ".", language, NULL);
+		add_notification_and_notify (client,
+					     key,
+					     (GConfClientNotifyFunc)generic_mozilla_int_notifier,
+					     info);
 		font_infos = g_list_append (font_infos, info);
 
-		sprintf (key, "%s_%s", CONF_RENDERING_FONT_FIXED_SIZE, lang_encode_item[i]);
-		info = g_strconcat ("size.fixed", ".", lang_encode_item[i], NULL);
-		galeon_notification_add (key,
-					 (GConfClientNotifyFunc)mozilla_font_size_notifier,
-					 info,
-				         &mozilla_notifiers);
+		sprintf (key, "%s_%s", CONF_RENDERING_FONT_FIXED_SIZE, language);
+		info = g_strconcat ("font.size.fixed", ".", language, NULL);
+		add_notification_and_notify (client,
+					     key,
+					     (GConfClientNotifyFunc)generic_mozilla_int_notifier,
+					     info);
 		font_infos = g_list_append (font_infos, info);
 
-		sprintf (key, "%s_%s", CONF_RENDERING_FONT_VAR_SIZE, lang_encode_item[i]);
-		info = g_strconcat ("size.variable", ".", lang_encode_item[i], NULL);
-		galeon_notification_add (key,
-					 (GConfClientNotifyFunc)mozilla_font_size_notifier,
-					 info,
-				         &mozilla_notifiers);
+		sprintf (key, "%s_%s", CONF_RENDERING_FONT_VAR_SIZE, language);
+		info = g_strconcat ("font.size.variable", ".", language, NULL);
+		add_notification_and_notify (client,
+					     key,
+					     (GConfClientNotifyFunc)generic_mozilla_int_notifier,
+					     info);
 		font_infos = g_list_append (font_infos, info);		
 	}
 }
@@ -659,7 +615,8 @@ static char *autodetect_charset_prefs[] =
         "ruprob",
         "zhcn_parallel_state_machine",
         "zhtw_parallel_state_machine",
-        "ukprob"
+        "ukprob",
+        "universal_charset_detector"
 };
 
 static void
