@@ -36,6 +36,7 @@
 #include <gtk/gtktoolbutton.h>
 #include <gtk/gtkalignment.h>
 #include <gtk/gtkmain.h>
+#include <gtk/gtkversion.h>
 #include <string.h>
 
 #define GALEON_FIND_TOOLBAR_GET_PRIVATE(object) (G_TYPE_INSTANCE_GET_PRIVATE ((object),GALEON_TYPE_FIND_TOOLBAR, GaleonFindToolbarPrivate))
@@ -192,7 +193,12 @@ tab_search_key_press_cb (GaleonEmbed *embed,
 			galeon_find_toolbar_open (toolbar, TRUE, TRUE);
 			return TRUE;
 		}
-		else if (event->keyval != GDK_space && autostart && event->length)
+		else if (autostart &&
+			 event->keyval != GDK_space && 
+			 event->keyval != GDK_KP_Enter &&
+			 event->keyval != GDK_ISO_Enter &&
+			 event->keyval != GDK_Return &&
+			 event->length)
 		{
 			GdkEvent *new_event;
 			GdkWindow *old_window;
@@ -439,7 +445,9 @@ galeon_find_toolbar_init (GaleonFindToolbar *toolbar)
 	gtk_tool_item_set_expand (priv->status_item, TRUE);
 	priv->status_label = gtk_label_new ("");
 	gtk_misc_set_alignment (GTK_MISC (priv->status_label), 0.0, 0.5);
+#if GTK_CHECK_VERSION(2,6,0)
 	gtk_label_set_ellipsize (GTK_LABEL (priv->status_label), PANGO_ELLIPSIZE_END);
+#endif
 	gtk_container_add (GTK_CONTAINER (priv->status_item), priv->status_label);
 	gtk_widget_show (priv->status_label);
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), priv->status_item, -1);
