@@ -86,7 +86,7 @@ enum
 	PROP_0,
 	PROP_TITLE,
 	PROP_ZOOM,
-	PROP_SECURITY,
+	PROP_SECURITY_LEVEL,
 	PROP_MESSAGE,
 	PROP_PROGRESS,
 	PROP_POPUP_BLOCKED,
@@ -232,7 +232,7 @@ galeon_tab_set_property (GObject *object,
 			break;
 		case PROP_TITLE:
 		case PROP_ZOOM:
-		case PROP_SECURITY:
+		case PROP_SECURITY_LEVEL:
 		case PROP_MESSAGE:
 		case PROP_PROGRESS:
 		case PROP_POPUP_BLOCKED:
@@ -261,7 +261,7 @@ galeon_tab_get_property (GObject *object,
 		case PROP_ZOOM:
 			g_value_set_int (value, tab->priv->zoom);
 			break;
-		case PROP_SECURITY:
+		case PROP_SECURITY_LEVEL:
 			g_value_set_int (value, tab->priv->security_level);
 			break;
 		case PROP_MESSAGE:
@@ -337,7 +337,7 @@ galeon_tab_class_init (GaleonTabClass *klass)
 							   100,
 							   G_PARAM_READABLE));
 	g_object_class_install_property (object_class,
-					 PROP_SECURITY,
+					 PROP_SECURITY_LEVEL,
 					 g_param_spec_int ("security-level",
 							   "Security Level",
 							   "The tab's security level",
@@ -347,7 +347,7 @@ galeon_tab_class_init (GaleonTabClass *klass)
 							    G_PARAM_READABLE));
 
 	g_object_class_install_property (object_class,
-					 PROP_SECURITY,
+					 PROP_LOAD_STATUS,
 					 g_param_spec_int ("load-status",
 							   "Load Status",
 							   "The status of the load",
@@ -364,7 +364,7 @@ galeon_tab_class_init (GaleonTabClass *klass)
 							      NULL,
 							      G_PARAM_READABLE));
 	g_object_class_install_property (object_class,
-					 PROP_ZOOM,
+					 PROP_PROGRESS,
 					 g_param_spec_int ("progress",
 							   "Progress",
 							   "The tab's load progress",
@@ -1429,8 +1429,11 @@ galeon_tab_dom_mouse_click_cb(GaleonEmbed *embed,
 	GaleonWindow *window;
 	guint button, modifier;
 	EmbedEventContext context;
-        
-	g_assert(GALEON_IS_EMBED_EVENT(event));
+	gboolean left_button, middle_button;
+	gboolean with_shift, with_control;
+	gboolean on_link, on_image;
+
+	g_return_val_if_fail (GALEON_IS_EMBED_EVENT(event), FALSE);
 
 	window = galeon_tab_get_window(tab);
 	g_return_val_if_fail(window != NULL, FALSE);
@@ -1439,30 +1442,36 @@ galeon_tab_dom_mouse_click_cb(GaleonEmbed *embed,
 	context = galeon_embed_event_get_context(event);
 	modifier = galeon_embed_event_get_modifier(event);
 
-	if (button == 1 && (context & EMBED_CONTEXT_LINK) &&
-	    (modifier & GDK_SHIFT_MASK))
+	left_button = (button == 1) ? 1 : 0;
+	middle_button = (button == 2) ? 1 : 0;
+
+	with_shift   = (modifier & GDK_SHIFT_MASK);
+	with_control = (modifier & GDK_CONTROL_MASK);
+
+	on_link  = (context & EMBED_CONTEXT_LINK);
+	on_image = (context & EMBED_CONTEXT_IMAGE);
+
+	if (left_button && on_link && with_shift && !(on_image && with_control))
 	{
 		galeon_embed_utils_download_event_property (embed, event, 
 							    FALSE, NULL, "link");
 	}
-	else if (button == 1 && (context & EMBED_CONTEXT_IMAGE) &&
-		 (modifier & GDK_SHIFT_MASK))
+	else if (left_button && on_image && with_shift)
 	{
 		galeon_embed_utils_save_event_property(embed, event, 
-						       TRUE,  /* always_ask_dir */
-						       FALSE, /* show_progress */
+						       FALSE, /* always_ask_dir */
+						       TRUE, /* show_progress */
 						       _("Save Image As..."),
 						       "image");
 	}
-	else if ((button == 1 && (context & EMBED_CONTEXT_LINK) &&
-		  (modifier & GDK_CONTROL_MASK)) ||
-		 (button == 2 && (context & EMBED_CONTEXT_LINK)))
+	else if ((left_button && on_link && with_control) ||
+		 (middle_button && on_link)) 
 	{
 		GaleonNewTabFlags flags = 0;
 		const GValue *value;
 		const gchar *link;
 
-		if (button == 2)
+		if (middle_button)
 		{
 			flags = galeon_shell_modifier_flags (modifier);
 		}
@@ -1480,7 +1489,7 @@ galeon_tab_dom_mouse_click_cb(GaleonEmbed *embed,
 			galeon_embed_load_url (galeon_tab_get_embed (tab), link);
 		}
 	}
-	else if (button == 2 &&
+	else if (middle_button && 
 		 (eel_gconf_get_integer(CONF_MOUSE_MIDDLE_BUTTON_ACTION) == 1 ||
 		  eel_gconf_get_integer(CONF_MOUSE_MIDDLE_BUTTON_ACTION) == 6) &&
 		 !(context & EMBED_CONTEXT_LINK ||
