@@ -40,11 +40,11 @@ typedef struct GaleonWindowPrivate GaleonWindowPrivate;
 
 #include "galeon-popup.h"
 
-#define GALEON_WINDOW_TYPE             (galeon_window_get_type ())
-#define GALEON_WINDOW(obj)             (GTK_CHECK_CAST ((obj), GALEON_WINDOW_TYPE, GaleonWindow))
+#define GALEON_TYPE_WINDOW             (galeon_window_get_type ())
+#define GALEON_WINDOW(obj)             (GTK_CHECK_CAST ((obj), GALEON_TYPE_WINDOW, GaleonWindow))
 #define GALEON_WINDOW_CLASS(klass)     (GTK_CHECK_CLASS_CAST ((klass), GALEON_WINDOW, GaleonWindowClass))
-#define IS_GALEON_WINDOW(obj)          (GTK_CHECK_TYPE ((obj), GALEON_WINDOW_TYPE))
-#define IS_GALEON_WINDOW_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), GALEON_WINDOW))
+#define GALEON_IS_WINDOW(obj)          (GTK_CHECK_TYPE ((obj), GALEON_TYPE_WINDOW))
+#define GALEON_IS_WINDOW_CLASS(klass)  (GTK_CHECK_CLASS_TYPE ((klass), GALEON_WINDOW))
 
 struct GaleonWindow 
 {
@@ -66,19 +66,6 @@ struct GaleonWindowClass
 	void (*active_embed_changed)	(GaleonWindow *window, GaleonEmbed *old_embed, GaleonEmbed *new_embed);
 };
 
-typedef enum 
-{
-	TitleControl,
-	LocationControl,
-	StatusbarSecurityControl,
-	StatusbarMessageControl,
-	StatusbarProgressControl,
-	StatusbarPopupBlockControl,
-	SpinnerControl,
-	WindowVisibilityControl,
-	PermissionControl,
-} ControlID;
-
 enum
 {
         GALEON_WINDOW_ADD_TAB_LAST = GUL_NOTEBOOK_INSERT_LAST,
@@ -103,6 +90,11 @@ void		galeon_window_bookmark_activate	  (GaleonWindow *w,
 						   GbBookmarkEventActivated *ev);
 
 gboolean	 galeon_window_can_close	  (GaleonWindow *w);
+
+void             galeon_window_update_edit_actions_sensitivity (GaleonWindow *w, gboolean hide);
+
+void             galeon_window_enable_edit_actions_sensitivity (GaleonWindow *w);
+
 /* Tabs */
 
 void          	 galeon_window_add_tab      	  (GaleonWindow *window, 
@@ -128,14 +120,6 @@ void		 galeon_window_reparent_tab	  (GaleonWindow *window,
 		                                   GaleonWindow *source,
 						   GaleonTab *tab);
 
-void		 galeon_window_set_tab_status	  (GaleonWindow *window,
-		                                   GaleonTab *tab,
-						   TabLoadStatus status);
-
-void		 galeon_window_set_tab_title	  (GaleonWindow *window,
-		                                   GaleonTab *tab,
-						   const char *title);
-
 void	      	 galeon_window_load_url      	  (GaleonWindow *window,
 					     	   const char *url);
 
@@ -149,8 +133,7 @@ gchar * 	 galeon_window_get_location_entry_location (GaleonWindow *window);
 void	 	 galeon_window_set_location_entry_location (GaleonWindow *window, 
 							    const gchar *location);
 
-void          	 galeon_window_update_control 	  (GaleonWindow *window,
-					    	   ControlID control);
+GtkWidget        *galeon_window_get_find_toolbar  (GaleonWindow *window);
 
 GtkWidget	 *galeon_window_get_statusbar	  (GaleonWindow *window);
 
@@ -168,18 +151,15 @@ GList 	 	 *galeon_window_get_tabs	  (GaleonWindow *window);
 
 EggEditableToolbar *galeon_window_get_toolbar	  (GaleonWindow *window);
 
-void		  galeon_window_site_visited	  (GaleonWindow *window, 
-						   const gchar *url, const gchar *title);
-
 void              galeon_window_clear_history     (GaleonWindow *window);
 
 /* Dialogs */
 void		  galeon_window_show_page_info	(GaleonWindow *window, PageInfoDialogPage page);
 
-void		  galeon_window_show_find	 (GaleonWindow *window);
-
 void		  galeon_window_show_history	  (GaleonWindow *window);
 
+void              galeon_window_show_js_console   (GaleonWindow *window);
+
 G_END_DECLS
 
 #endif
