@@ -46,6 +46,7 @@
 #include <gtk/gtklabel.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkalignment.h>
+#include <gtk/gtkversion.h>
 #include <libgnomeui/gnome-icon-lookup.h>
 #include <libgnome/gnome-help.h>
 
@@ -715,7 +716,7 @@ gul_gui_image_set_from_mime_type (GtkWidget  *image,
 }
 
 /**
- * gul_image_button_new:
+ * gul_gul_image_button_new:
  * @label_text: the text of the button, with an underscore in front of the
  *              mnemonic character
  * @image_stock_id: the name of the stock image
@@ -729,6 +730,18 @@ gul_gui_image_set_from_mime_type (GtkWidget  *image,
 GtkWidget *
 gul_gui_image_button_new (const char *label_text, const char *image_stock_id)
 {
+#if GTK_CHECK_VERSION(2,6,0)
+	GtkWidget *button;
+	GtkWidget *image;
+
+	button = gtk_button_new_with_mnemonic  (label_text);
+	image = gtk_image_new_from_stock (image_stock_id, GTK_ICON_SIZE_BUTTON);
+
+	gtk_button_set_image (GTK_BUTTON (button), GTK_WIDGET (image));
+
+	return button;
+#else
+
 	GtkWidget *button;
 	GtkWidget *label;
 	GtkWidget *image;
@@ -754,6 +767,7 @@ gul_gui_image_button_new (const char *label_text, const char *image_stock_id)
 	gtk_widget_show_all (align);
 
 	return button;
+#endif
 }
 
 /**
