@@ -40,6 +40,7 @@
 #include <gtk/gtkimage.h>
 #include <gtk/gtkmain.h>
 #include <gtk/gtkeventbox.h>
+#include <gtk/gtkversion.h>
 
 #include <glib-object.h>
 #include <glib/gi18n.h>
@@ -775,9 +776,14 @@ tab_build_label (GulNotebook *nb, GtkWidget *child)
 
 	window = gtk_widget_get_toplevel (GTK_WIDGET (nb));
 	
+#if !GTK_CHECK_VERSION(2,6,0)
 	/* Add some space between the label and the close button, this
 	 * should be the same as the left-padding for the label */
 	hbox = gtk_hbox_new (FALSE, SPACING);
+#else
+	/* The previous is not useful with ellipsizing */
+	hbox = gtk_hbox_new (FALSE, 0);
+#endif
 
 	/* setup close button, zero out {x,y}thickness to get smallest possible
 	 * size */
@@ -806,6 +812,12 @@ tab_build_label (GulNotebook *nb, GtkWidget *child)
 	label_hbox = gtk_hbox_new (FALSE, 0);
         label = gtk_label_new (_("Untitled"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.00, 0.5);
+#if GTK_CHECK_VERSION(2,6,0)
+	gtk_label_set_ellipsize (GTK_LABEL (label), PANGO_ELLIPSIZE_END);
+	/* See bug 170378 */
+	gtk_label_set_single_line_mode (GTK_LABEL (label), TRUE);
+#endif
+
 
 	alignment = g_object_new (GTK_TYPE_ALIGNMENT,
 				  "xalign",       0.0,
